@@ -34,7 +34,7 @@ class MySQL(object):
             self.db.rollback()
 
     # 保存到mysql
-    def save(self, item, table_name):
+    def write(self, item, table_name):
         self.db.ping(reconnect=True)
         data = dict(item)
         keys = ', '.join(data.keys())
